clear
cap log close

mat drop _all

	global prog   "\\...\CLEAN\prog"
	global source "\\...\source_data\no"
	global data   "\\...\CLEAN\data"
	global output "\\...\CLEAN\data"
    global temp   "\\...\data\no-backup"

log using $prog\TaxesNorway2006CLEAN.log, replace

/*****************************************************************************
*
***   Computes the marginal tax on labor and wealth in Norway in 2006      ***
*				   		      
******************************************************************************/

use $source\dsb_2006.dta, clear
keep FNR_NN PERSONINNT_NAERING
duplicates drop FNR_NN, force
rename FNR_NN ID
rename PERSONINNT_NAERING i_labor_selfempl
replace i_labor_selfempl=0 if i_labor_selfempl==.
sort ID
save $temp\selfempl06.dta, replace

**

use $data\big06.dta, clear

drop if i_inc == 0 & taxwealth == 0
merge 1:1 ID using  $temp\selfempl06.dta
drop if _m==2
drop _m
replace i_labor_selfempl=0 if i_labor_selfempl==.

***************************************
************ LABOR INCOME *************
***************************************

/* Parameters of the tax system */
global exemptionAlm = 35400
global exemption1 = 394000
global exemption2 = 750000
global payroll = 0.078
global payrollPens = 0.03
global alminnelig = 0.28
global surtax1 = 0.09
global surtax2 = 0.03

/* Actual tax payments */
* Define actual income tax bill *
gen payrollpay = max(0,i_wage)*$payroll
gen payrollPenspay = max(0,i_pension )*$payrollPens
gen almtaxpay = max(0,i_alminnelig_inntekt-$exemptionAlm)*$alminnelig
gen surtax1pay = max(0,i_wage + i_pension + i_labor_selfempl - $exemption1)*$surtax1
gen surtax2pay = max(0,i_wage + i_pension + i_labor_selfempl - $exemption2)*$surtax2
gen totalinctax = payrollpay + payrollPenspay + almtaxpay + surtax1pay + surtax2pay 

/* Counterfactual tax payments with labor income 1,000 NOK higher*/
* Auxilary variables *
gen i_alminnelig_inntektX = i_alminnelig_inntekt + 1000
gen i_wageX = i_wage + 1000

* Define counterfactual income tax bill *
gen payrollpayX  = max(0,i_wageX)*$payroll
gen almtaxpayX   = max(0,i_alminnelig_inntektX-$exemptionAlm)*$alminnelig
gen surtax1payX  = max(0,i_wageX + i_pension + i_labor_selfempl - $exemption1)*$surtax1
gen surtax2payX  = max(0,i_wageX + i_pension + i_labor_selfempl - $exemption2)*$surtax2
gen totalinctaxX = (payrollpayX + payrollPenspay + almtaxpayX + surtax1payX + surtax2payX) 

/* Marginal tax rate on labor income */
gen rate_labor = (totalinctaxX - totalinctax) / 1000

sum rate_labor, det
count if rate_labor==.

sum i_alminnelig_inntekt, det
gen alm = max(0,i_alminnelig_inntekt-$exemptionAlm)
count if alm >100000 & alm <.

gen sur1  = max(0,i_wageX + i_pension + i_labor_selfempl - $exemption1)
gen sur2  = max(0,i_wageX + i_pension + i_labor_selfempl - $exemption2)
sum sur1, det
sum sur2, det

count if sur1==.
count if sur2==.
count if sur1>0
count if sur2>0

sum rate_labor, det
count if rate_labor>= 0.358
count if rate_labor>= 0.448
count if rate_labor==.478
count if rate_labor>.477
count if rate_labor>.477 & rate_labor<.478

***************************************
************    WEALTH       **********
***************************************

/* Parameters of the tax system */

global wthreshold1 = 200000
global wthreshold2 = 540000
global wrate1 = 0.009
global wrate2 = 0.002


/* Define marginal portfolio weights */
global weight_share = 1.0
global weight_house = 0.0
global weight_bond = 0.0

global return = ($weight_share * 0.045) + ($weight_house * 0.009) + ($weight_bond * 0.019)
di "Global return: $return "

/* Define tax value weights, how much of an 1 NOK increas in an asset type 
matters for taxable wealth */
global taxv_house = 0.2 
global taxv_share = 0.8

* Now, 1 NOK in additional wealth means that taxable wealth invreases by Y:
global Y = $weight_bond + ($weight_house * $taxv_house) + ($weight_share * $taxv_share)
di "Factor Y, increase in taxable wealth if real wealth increases by 1: $Y "

***
/* Actual tax payments */

* Define actual tax bills for wealth 
gen wealthtax1 = max(0, taxwealth - $wthreshold1)*$wrate1
gen wealthtax2 = max(0, taxwealth - $wthreshold2)*$wrate2
gen wealthtax_Tot= wealthtax1 + wealthtax2
*test: distribution of pre-tax rate
gen prewealthtax_rate=wealthtax_Tot/taxwealth

/* Counterfactual tax payments with income / wealth 1 NOK higher */

* Auxilary variables *
gen i_alminnelig_inntektY = i_alminnelig_inntekt + $return * 1000
gen taxwealthY = taxwealth + $Y * 1000

* Define counterfactual tax bill capital, assuming other income as given *
gen almtaxpayY = max(0,i_alminnelig_inntektY - $exemptionAlm)*$alminnelig
gen wealthtax1Y = max(0, taxwealthY - $wthreshold1)*$wrate1
gen wealthtax2Y = max(0, taxwealthY - $wthreshold2)*$wrate2
gen wealthtax_TotY= wealthtax1Y + wealthtax2Y

* 80-percent-rule
*  Reduction in wealth tax if (assessed wealth tax + tax on ordinary income) exceeds 80% of ordinary income, 
*  but max reduction until wealth tax contributes 0.6% of total wealth above 1 million NOK 
	gen maximize_reduction = 0
	replace maximize_reduction = 1 if avoid_80reduction == 1 & 0.99 * (taxwealth - 1000000) * 0.006 <= tax_wealth <= 1.01 * (taxwealth - 1000000) * 0.006
	
/* Marginal tax increase by investing an additional NOK 1,000 */
    gen margwealthtax = wealthtax_TotY - wealthtax_Tot
    gen margwealthtax2 = margwealthtax // marginal wealth tax rate taking into account ceiling
	replace margwealthtax2 = 0 if avoid_80reduction == 1
	replace margwealthtax2 = $Y * 1000 * 0.006  if avoid_80reduction == 1 & maximize_reduction == 1
	
	gen margcaptax =  $return * 1000 *$alminnelig
	sum margcaptax margwealthtax, det
	
    gen rate_capital =  (margwealthtax + margcaptax)  / ($return * 1000)
	gen rate_capital2 = (margwealthtax2 + margcaptax) / ($return * 1000)
 
    sum rate_capital rate_capital2 prewealthtax_rate, det
    sum rate_capital rate_capital2 prewealthtax_rate if avoid_80reduction == 1, det
********************************************************************************
********************************************************************************

/* Marginal tax rates, household level */

foreach yr in  06 {

	collapse (sum) mwealth i_inc tax_all (max) rate_* prewealthtax_rate avoid_80reduction maximize_reduction, by(ind_hhold) 
    gperc mwealth i_inc tax_all  rate_labor rate_capital rate_capital2 avoid_80reduction maximize_reduction prewealthtax_rate, matname(rate`yr')
    
		clear
		svmat rate`yr', names(col)
		qui compress
		export excel using "$output\marginal_tax_rate`yr'.xlsx", first(var) replace 
    }



**********
clear
log close
