clear
set more off


	global prog   "\\...\CLEAN\prog"
	global source "\\...\source_data\no"
	global data   "\\...\CLEAN\data"
    global temp   "\\...\data\no-backup"

cap log close
log using $prog\makedata2_incomeCLEAN.log, replace
 
/************************************************************************************
* Note: raw data modified prior to delivery in order to keep anonymity of observations
*
* Make consistent income variables acrosss years and data sources.
* Save as the annual data sets $data\income_`yr'.dta
*  
* NOTATION:
*  - income variables have prefix i_
*  - capital gain variables have prefix g_ (these are not kept in the final data set, but can be collected if necessary)
*  - capital loss variables have prefix l_ (these are not kept in the final data set, but can be collected if necessary)
*  - disclosed income variables (from the tax stataments) have prefix di_
* 
* Definitions of the raw tax variables change somewhat over time. The goal is to construct as consistent variables as posssible 
* 
* INCOME DECOMPOSITION over time
*  2009-2013: i_wage + i_business + i_pension + i_housing + i_deposits + i_bonds + i_dividends + i_otherfin + i_f_pension + i_f_deposits + i_f_bonds + i_f_shares + i_f_nokus 
*  2003-2008: i_wage + i_business + i_pension + i_housing + i_deposits + i_bonds + i_dividends + i_otherfin + i_f_pension + i_f_fincapital + i_f_housing
*  2001-2002: i_wage + i_business + i_pension + i_housing + i_deposits + i_bonds + i_dividends + i_otherfin + i_f_fincapital + i_f_housing
*   
*  CAPITAL GAIN DECOMPOSITION over time
*  2009-2013: g_shares - l_shares + g_housing - l_housing - l_bonds - l_other
*  2001-2008: g_fincapital - l_fincapital + g_housing - l_housing 
*
************************************************************************************/


********************************************************************************* 
*********************************2009-2013 SL data ******************************
*********************************************************************************
 *correction of original data: 
 *  1) 2011-2013:
 *		add new pension variables: 
 *          i_pension_folketrygd, i_pension_other 
 *  	add the missing business income:
 *		    i_bus_add  
 *		add the new foreign pension and housing income:
 *		  i_f_pens_add, i_f_hous_add
 *		
 *  2) 2009-2010:
 *		add new pension variables: 
 *          i_pension_folketrygd, i_pension_other 
 *  	add the missing business income:
 *		    i_bus_add
********************************************************************************* 

* Fix duplicates  - keep observation with higher wealth
foreach yr in 11 12 13  {
use $source\sl_20`yr'.dta, clear
  rename fnr_nn ID
  rename aar year
  drop if l_alm_innt==. & l_nettoformue==. & l_3_1_11_utl==. 
  sort ID
  duplicates tag ID , generate(dupl)
  tab dupl
save $temp\temp1.dta, replace
  keep if dupl>0
  replace l_nettoformue=0 if l_nettoformue==. 
  sort ID l_nettoformue
  duplicates drop ID l_nettoformue, force
  sort ID l_nettoformue
save $temp\temp2dupl.dta, replace
  keep ID l_nettoformue
  collapse (max) l_nettoformue , by(ID)
  sort ID l_nettoformue
  merge ID l_nettoformue using $temp\temp2dupl.dta
  keep if _m==3
  drop _m dupl
save $temp\temp3.dta, replace

use $temp\temp1.dta, clear
  drop if dupl>0
  drop dupl
  append using $temp\temp3.dta
  sort ID
  duplicates report ID

* Add on variables that were missing or incomplete in first data delivery:
  merge 1:1 ID using $source\add_pension_`yr'.dta
  drop if _m==2
  drop _m
  merge 1:1 ID using $source\add_forpens_`yr'.dta
  drop if _m==2
  drop _m
  merge 1:1 ID using $source\add_bus_`yr'.dta
  drop if _m==2
  drop _m

  rename l_2_1_1_belop i_wage
  rename l_3_1_1 i_interests
  rename l_obliinnt_innl i_bonds
  rename l_kapinnt_annet i_otherfin
  rename l_3_1_10 i_div
  rename l_kapgev_aksj i_kg_shares 
  rename l_tap_aksje l_shares 
  rename l_3_3_obl l_bonds 
  rename l_2_8_4 i_housing_gain 
  rename l_tap_annet l_other
  rename l_alm_innt i_alminnelig_inntekt
  rename l_3_1_11_utl i_f_interests
  rename l_3_1_11_utl_obl i_f_bonds
  rename l_kapgev_aksj_utl i_f_kg
  rename l_innt_nokus i_f_nokus
  label var year "year"
  label var ID "personal identifyer"
  label var i_alminnelig_inntekt "-alminnelig- income net of all deductions"
  label var i_interests "domestic interest income"
  label var i_kg_shares "domestic taxable realized capital gains from shares"
  label var i_bonds "domestic income from bonds"
  label var i_f_nokus  "foreign income from nokus-countries"
  label var i_f_bonds  "foreign income from bonds"
  label var i_f_interests "foreign interest income"
  label var i_otherfin  "other financial income"
  label var i_housing_gain  "domestic captial gains realized housing"
  label var i_pension_folketrygd  "domestic pension income from public pension - folketrygden"
  label var i_pension_other  "domestic other pension income, not public pension"
  
 global incvars "i_f_pens_add i_f_hous_add i_pension_folketrygd i_pension_other i_bus_add  i_wage i_interests i_bonds i_otherfin i_div i_kg_shares l_shares l_inng_fast_eiend l_3_3_12 l_bonds i_housing_gain l_other i_alminnelig_inntekt i_f_interests i_f_bonds i_f_kg i_f_nokus l_2_7_driftsres l_2_2_2_belop l_2_2_3_belop l_1_5_3 p_3_1_11_utl_obl p_3_1_11_utl p_kapgev_aksj_utl p_innt_nokus p_alm_innt p_2_2_2_belop p_2_2_3_belop"  
  foreach var of global incvars {
  replace `var'=0 if `var'==.
 }

*domestic variables
  rename i_bus_add i_business
  gen i_housing = l_inng_fast_eiend  - l_3_3_12 
  label variable i_div "dividend income: dividends from domestic shares (listed + unlisted) + certificates + mutual funds + shares in commandites"
  label variable i_business "business income: income from unincorporated businesses + farm + forest"
  label variable i_housing "Housing rents, net inocome from housing"
  label variable i_wage "domestic wage income"
*variables related to foreign countries
  rename i_f_hous_add i_f_housing 
  gen i_f_pension = l_2_2_2_belop  + l_2_2_3_belop + i_f_pens_add
  drop i_f_pens_add
  gen i_f_int =i_f_interests + i_f_bonds 
  gen i_f_capinc= i_f_int + i_f_kg + i_f_nokus
  gen i_f_inc=i_f_capinc + i_f_housing + i_f_pension
  label variable i_f_int "foreign interest income: interest from foreign deposits + foreign bonds"
  label variable i_f_kg "foreign capital gains"
  label variable i_f_pension "foreign pension income"
  label variable i_f_inc "total foreign income"
  label variable i_f_capinc "total foreign capital income"

* Create income variables, domestic+foreign income 
  gen i_int=i_interests + i_bonds + i_f_int
  label variable i_int "interest income: interest from domestic deposits + bonds"
  gen i_kg= i_kg_shares + i_housing_gain + i_f_kg
  label variable i_kg "realized domestic and foreign capital gains (equities + housing)" 
  gen i_pension= i_pension_folketrygd + i_pension_other + i_f_pension
  label variable i_pension "pension income domestic and foreign(= pension distributions)"
  gen i_inc= i_wage + i_int + i_div + i_pension + i_business + i_housing + i_otherfin
  label variable i_inc "total taxable income excluding KG"
 
*define income with capital gains (where capital gains are set to zero when negative)*
  gen i_inckg = i_inc + max(i_kg,0) 
  label var i_inckg "total income incl. KG"
 
* labor + mixed income 
  gen i_linc=i_wage + i_pension + i_business
  label var i_linc "total incme from labor and self-employed business" 
  rename l_1_5_3 i_inheritance
  label variable i_inheritance "gift and inheritances received during the year"

*compute disclosed income by subtracting stated values from final assessed values*
  gen di_pension = i_f_pension - p_2_2_2_belop - p_2_2_3_belop
  gen di_interests = i_f_interests - p_3_1_11_utl
  gen di_bonds = i_f_bonds - p_3_1_11_utl_obl
  gen di_shares = i_f_kg - p_kapgev_aksj_utl
  gen di_nokus = i_f_nokus - p_innt_nokus
  gen di_income = i_alminnelig_inntekt - p_alm_innt if alm_innt_p_avrundet~="J" & alm_innt_l_avrundet~="J"
  label var di_interests "disclosed foreign interest income, tax statement"
  label var di_bonds "disclosed foreign bond income, tax statement"
  label var di_shares "disclosed foreign capital gain from shares, tax statement"
  label var di_nokus "disclosed foreign income NOKUS countries , tax statement"
  label var di_income "disclosed alminnelig inntekt, tax statement"
  gen di_f_capinc=i_f_capinc - p_3_1_11_utl_obl - p_3_1_11_utl - p_kapgev_aksj_utl - p_innt_nokus 
  label var di_f_capinc "disclosed foreign cpaital income"
 
  keep ID year i_*  di_* 

  compress
  sort ID
  d, fullname
  sum
save  $data\income_`yr'.dta, replace
}

********************************************************************************
* No info on foreign pension or housing for 2009 and 2010
********************************************************************************

* Fix duplicates  - keep observation with higher wealth
foreach yr in 09 10  {
use $source\sl_20`yr'.dta, clear
  drop if l_alm_innt==. & l_nettoformue==. & l_3_1_11_utl==. 
  rename fnr_nn ID
  rename aar year
  sort ID
  duplicates tag ID , generate(dupl)
  tab dupl
save $temp\temp1.dta, replace
  keep if dupl>0
  replace l_nettoformue=0 if l_nettoformue==. 
  sort ID l_nettoformue
  duplicates drop ID l_nettoformue, force
  sort ID l_nettoformue
save $temp\temp2dupl.dta, replace
  keep ID l_nettoformue
  collapse (max) l_nettoformue , by(ID)
  sort ID l_nettoformue
  merge ID l_nettoformue using $temp\temp2dupl.dta
  keep if _m==3
  drop _m dupl
save $temp\temp3.dta, replace

use $temp\temp1.dta, clear
  drop if dupl>0
  drop dupl
  append using $temp\temp3.dta
  sort ID
  duplicates report ID
 
* Add on variables that were missing or incomplete: 
  merge 1:1 ID using $source\add_pension_`yr'.dta
  drop if _m==2
  drop _m 
  merge 1:1 ID using $source\add_bus_`yr'.dta
  drop if _m==2
  drop _m
  
  rename l_2_1_1_belop i_wage
  rename l_3_1_1 i_interests
  rename l_obliinnt_innl i_bonds
  rename l_kapinnt_annet i_otherfin
  rename l_3_1_10 i_div
  rename l_kapgev_aksj i_kg_shares 
  rename l_tap_aksje l_shares 
  rename l_3_3_obl l_bonds 
  rename l_2_8_4 i_housing_gain 
  rename l_tap_annet l_other
  rename l_alm_innt i_alminnelig_inntekt
  rename l_3_1_11_utl i_f_interests
  rename l_3_1_11_utl_obl i_f_bonds
  rename l_kapgev_aksj_utl i_f_kg
  rename l_innt_nokus i_f_nokus
  label var year "year"
  label var ID "personal identifyer"
  label var i_alminnelig_inntekt "-alminnelig- income net of all deductions"
  label var i_interests "domestic interest income"
  label var i_kg_shares "domestic taxable realized capital gains from shares"
  label var i_bonds "domestic income from bonds"
  label var i_f_nokus  "foreign income from nokus-countries"
  label var i_f_bonds  "foreign income from bonds"
  label var i_f_interests "foreign interest income"
  label var i_otherfin  "other financial income"
  label var i_housing_gain  "domestic captial gains realized housing"
  label var i_pension_folketrygd  "domestic pension income from public pension - folketrygden"
  label var i_pension_other  "domestic other pension income, not public pension"
  
 global incvars "i_pension_folketrygd i_pension_other i_bus_add i_wage i_interests i_bonds i_otherfin i_div i_kg_shares l_shares l_inng_fast_eiend l_3_3_12 l_bonds i_housing_gain l_other i_alminnelig_inntekt i_f_interests i_f_bonds i_f_kg i_f_nokus l_2_7_driftsres l_2_2_2_belop l_2_2_3_belop l_1_5_3 p_3_1_11_utl_obl p_3_1_11_utl p_kapgev_aksj_utl p_innt_nokus p_alm_innt p_2_2_2_belop p_2_2_3_belop" 
 foreach var of global incvars {
  replace `var'=0 if `var'==.
 }
 
*domestic variables
  rename i_bus_add i_business
  gen i_housing = l_inng_fast_eiend  - l_3_3_12 
  label variable i_div "dividend income: dividends from domestic shares (listed + unlisted) + certificates + mutual funds + shares in commandites"
  label variable i_business "business income: income from unincorporated businesses + farm + forest"
  label variable i_housing "Housing rents, net inocome from housing"
  label variable i_wage "domestic wage income"

*foreign variables
  gen i_f_pension = l_2_2_2_belop  + l_2_2_3_belop 
  gen i_f_int =i_f_interests + i_f_bonds 
  gen i_f_capinc= i_f_int + i_f_kg + i_f_nokus
  gen i_f_inc=i_f_capinc  + i_f_pension
  label variable i_f_int "foreign interest income: interest from foreign deposits + foreign bonds"
  label variable i_f_kg "foreign capital gains"
  label variable i_f_pension "foreign pension income"
  label variable i_f_inc "total foreign income"
  label variable i_f_capinc "total foreign capital income"

* Create income variables, domestic+foreign income 
  gen i_int=i_interests + i_bonds + i_f_int
  label variable i_int "interest income: interest from domestic deposits + bonds"
  gen i_kg= i_kg_shares + i_housing_gain + i_f_kg
  label variable i_kg "realized domestic and foreign capital gains (equities + housing)"
  gen i_pension= i_pension_folketrygd + i_pension_other + i_f_pension
  label variable i_pension "pension income domestic and foreign(= pension distributions)"
  gen i_inc= i_wage + i_int + i_div + i_pension + i_business + i_housing + i_otherfin
  label variable i_inc "total taxable income excluding KG"
 
*define income with capital gains (where capital gains are set to zero when negative)*
  gen i_inckg = i_inc + max(i_kg,0) 
  label var i_inckg "total income incl. KG"
 
* labor + mixed income 
  gen i_linc=i_wage + i_pension + i_business
  label var i_linc "total incme from labor and self-employed business" 
  rename l_1_5_3 i_inheritance
  label variable i_inheritance "gift and inheritances received during the year"

*compute disclosed income by subtracting stated values from final assessed values 
  gen di_pension = i_f_pension - p_2_2_2_belop - p_2_2_3_belop
  gen di_interests = i_f_interests - p_3_1_11_utl
  gen di_bonds = i_f_bonds - p_3_1_11_utl_obl
  gen di_shares = i_f_kg - p_kapgev_aksj_utl
  gen di_nokus = i_f_nokus - p_innt_nokus
  gen di_income = i_alminnelig_inntekt - p_alm_innt if alm_innt_p_avrundet~="J" & alm_innt_l_avrundet~="J"
  label var di_interests "disclosed foreign interest income, tax statement"
  label var di_bonds "disclosed foreign bond income, tax statement" 
  label var di_shares "disclosed foreign capital gain from shares, tax statement"
  label var di_nokus "disclosed foreign income NOKUS countries , tax statement"
  label var di_income "disclosed alminnelig inntekt, tax statement"
  gen di_f_capinc=i_f_capinc - p_3_1_11_utl_obl - p_3_1_11_utl - p_kapgev_aksj_utl - p_innt_nokus 
  label var di_f_capinc "disclosed foreign cpaital income"
	
  keep ID year i_* di_* 
  compress
  sort ID
  d, fullname
  sum
save  $data\income_`yr'.dta, replace
}   
     
********************************************************************************* 
*********************************2001-2008 data *********************************
********************************************************************************* 
 * correction of origianal data: 
 *  1) 2007-2008: 
 *		add new pension variables: 
 *        i_pension_folketrygd, _pension_other
 *
 *  2) 2001-2005: 
 *		add the missing dividend income:
 *		   i_div_add
 *		add new pension variables: 
 *        i_pension_folketrygd, _pension_other
 *
 * For the years 2001-2008, L_ALM_INNT does not exist --> L_3_4
 * For the years 2001 and 2002, the variable L_2_7_9 does not exist --> L_NARINGSINNT  
********************************************************************************* 

* Fix duplicates  - keep observation with higher wealth
foreach yr in 06 07 08  {
use $source\dsb_20`yr'.dta, clear
  rename FNR_NN ID
  rename aar year
  drop if L_3_4==. & L_4_9==. & L_3_1_11==.
  sort ID
  duplicates tag ID , generate(dupl)
  tab dupl
save $temp\temp1.dta, replace 
  keep if dupl>0
  rename L_4_9 L_NETTOFORMUE
  replace L_NETTOFORMUE=0 if L_NETTOFORMUE==. 
  sort ID L_NETTOFORMUE
  duplicates drop ID L_NETTOFORMUE, force
  sort ID L_NETTOFORMUE
save $temp\temp2dupl.dta, replace
  keep ID L_NETTOFORMUE
  collapse (max) L_NETTOFORMUE , by(ID)
  sort ID L_NETTOFORMUE
  merge ID L_NETTOFORMUE using $temp\temp2dupl.dta
  keep if _m==3
  drop _m dupl
save $temp\temp3.dta, replace
use $temp\temp1.dta, clear
  drop if dupl>0
  drop dupl
  append using $temp\temp3.dta
  sort ID
  duplicates report ID
 
* Add on variables that were missing or incomplete:
  merge 1:1 ID using $source\add_pension_`yr'.dta
  drop if _m==2
  drop _m
  d, fullname 

  rename L_2_1_6 i_wage
  rename L_3_1_1 i_interests
  rename OBLINNT_INNL i_bonds
  rename ANDRE_KAPINNT i_otherfin
  rename SKPL_KAPGEV i_kg_shares 
  rename L_2_8_4 i_housing_gain 
  rename L_3_4 i_alminnelig_inntekt
  rename L_2_2_2_4 i_f_pension
  rename L_2_8_5 i_f_housing
  label var year "year"
  label var ID "personal identifyer"
  label var i_alminnelig_inntekt "-alminnelig- income net of all deductions"
  label var i_interests "domestic interest income"
  label var i_kg_shares "domestic taxable realized capital gains from shares"
  label var i_bonds "domestic income from bonds"
  label var i_otherfin  "other financial income"
  label var i_housing_gain  "domestic captial gains realized housing"
  label var i_pension_folketrygd  "domestic pension income from public pension - folketrygden"
  label var i_pension_other  "domestic other pension income, not public pension"

 global incvars "SKPL_UTB i_pension_folketrygd i_pension_other  i_wage i_interests i_bonds i_otherfin i_kg_shares   i_housing_gain  i_alminnelig_inntekt  i_f_pension i_f_housing   L_1_5_3  L_3_1_11 P_3_1_11 P_3_4  L_3_3_6 L_2_7_9 " 
 foreach var of global incvars {
  replace `var'=0 if `var'==.
 }
 
* domestic variables
  rename L_2_7_9 i_business
  gen i_div=SKPL_UTB
  label variable i_div "domestic dividend income"
  label variable i_business "business income: income from unincorporated businesses + farm + forest"
  label variable i_housing "Housing rents, net inocome from housing"
  label variable i_wage "domestic wage income"
 
* foreign variables
  rename  L_3_1_11 i_f_capinc
  gen i_f_inc=i_f_capinc  + i_f_pension
  label variable i_f_pension "foreign pension income"
  label variable i_f_inc "total foreign income"
  label variable i_f_capinc "total foreign capital income"
  label variable i_div "dividend income: dividends from domestic shares (listed + unlisted) + certificates + mutual funds + shares in commandites"
  label variable i_business "business income: income from unincorporated businesses + farm + forest"
  label variable i_housing "Housing rents, net inocome from housing"
  label variable i_wage "domestic wage income"

* Create income variables, domestic+foreign income 
  gen i_int=i_interests + i_bonds + i_f_capinc
  label variable i_int "interest income: interest from domestic deposits + bonds"
  gen i_kg= i_kg_shares + i_housing_gain 
  label variable i_kg "realized domestic and foreign capital gains (equities + housing)"
  gen i_pension= i_pension_folketrygd + i_pension_other + i_f_pension
  label variable i_pension "pension income domestic and foreign(= pension distributions)"
  gen i_inc= i_wage + i_int + i_div + i_pension + i_business + i_housing + i_otherfin
  label variable i_inc "total taxable income excluding KG"
 
*define income with capital gains (where capital gains are set to zero when negative)*
  gen i_inckg = i_inc + max(i_kg,0) 
  label var i_inckg "total income incl. KG"
 
* labor + mixed income 
  gen i_linc=i_wage + i_pension + i_business
  label var i_linc "total incme from labor and self-employed business" 
  rename L_1_5_3 i_inheritance
  label variable i_inheritance "gift and inheritances received during the year"
	
* compute disclosed income by subtracting stated values from final assessed values
  gen di_income = i_alminnelig_inntekt - P_3_4 
  label var di_income "disclosed alminnelig inntekt, tax statement"
  gen di_f_capinc=i_f_capinc-P_3_1_11
  label var di_f_capinc "disclosed foreign cpaital income"

  keep ID year i_* di_* 
  compress
  sort ID
  d, fullname
  sum
save  $data\income_`yr'.dta, replace
}

********************************************************************************
*Until 2005, less detailed income data
********************************************************************************
* Fix duplicates  - keep observation with higher wealth
foreach yr in  03 04 05    {
use $source\dsb_20`yr'.dta, clear
  rename FNR_NN ID
  rename aar year
  drop if L_3_4==. & L_4_9==. & L_UTL_KAPINTT==.
  sort ID
  duplicates tag ID , generate(dupl)
  tab dupl
save $temp\temp1.dta, replace
  keep if dupl>0
  rename L_4_9 L_NETTOFORMUE
  replace L_NETTOFORMUE=0 if L_NETTOFORMUE==. 
  sort ID L_NETTOFORMUE
  duplicates drop ID L_NETTOFORMUE, force
  sort ID L_NETTOFORMUE
save $temp\temp2dupl.dta, replace
  keep ID L_NETTOFORMUE
  collapse (max) L_NETTOFORMUE , by(ID)
  sort ID L_NETTOFORMUE
  merge ID L_NETTOFORMUE using $temp\temp2dupl.dta
  keep if _m==3
  drop _m dupl
save $temp\temp3.dta, replace
use $temp\temp1.dta, clear
  drop if dupl>0
  drop dupl
  append using $temp\temp3.dta
  sort ID
  duplicates report ID

* Add on variables that were missing or incomplete
  merge 1:1 ID using $source\add_pension_`yr'.dta
  drop if _m==2
  drop _m
  merge 1:1 ID using $source\add_div_`yr'.dta
  drop if _m==2
  drop _m
  sort ID
  d, fullname 
 
  rename L_2_1_6 i_wage
  rename L_3_1_1 i_interests
  rename OBLINNT_INNL i_bonds
  rename ANDRE_KAPINNT i_otherfin
  rename L_3_1_5 i_kg_shares 
  rename L_2_8_4 i_housing_gain 
  rename L_3_4 i_alminnelig_inntekt
  rename L_2_2_2_4 i_f_pension
  rename L_2_8_5 i_f_housing
  label var year "year"
  label var ID "personal identifyer"
  label var i_alminnelig_inntekt "-alminnelig- income net of all deductions"
  label var i_interests "domestic interest income"
  label var i_kg_shares "domestic taxable realized capital gains from shares"
  label var i_bonds "domestic income from bonds"
  label var i_otherfin  "other financial income"
  label var i_housing_gain  "domestic captial gains realized housing"
  label var i_pension_folketrygd  "domestic pension income from public pension - folketrygden"
  label var i_pension_other  "domestic other pension income, not public pension"

 global incvars "P_2_8_5 P_2_2_2_4 L_3_1_4 L_UTL_KAPINTT P_UTL_KAPINNT i_div_add i_pension_folketrygd i_pension_other   i_wage i_interests i_bonds i_otherfin i_kg_shares   i_housing_gain  i_alminnelig_inntekt  i_f_pension i_f_housing   L_1_5_3  P_3_4  L_3_3_6 L_2_7_9  P_2_7_9" 
 foreach var of global incvars {
  replace `var'=0 if `var'==.
 }

* Domestic variables 
  gen i_div=L_3_1_4+i_div_add
  drop i_div_add
  rename L_2_7_9 i_business
  label variable i_div "domestic dividend income"
  label variable i_business "business income: income from unincorporated businesses + farm + forest"
  label variable i_housing "Housing rents, net inocome from housing"
  label variable i_wage "domestic wage income"
  
* Foreign variables
  rename L_UTL_KAPINTT i_f_capinc
  gen i_f_inc=i_f_capinc  + i_f_pension 
  label variable i_f_pension "foreign pension income"
  label variable i_f_inc "total foreign income"
  label variable i_f_capinc "total foreign capital income"

* Create income variables, domestic+foreign income 
* Only have total foreign capipital income befoer 2006, so variables will not be consistent over time. 
* i_int is defined as indlucing interest income from 2006 and ownard, but befoere, it also includes all kinds of capital incomes
  gen i_int=i_interests + i_bonds + i_f_capinc
  label variable i_int "interest income: interest from domestic deposits + bonds"
  gen i_kg= i_kg_shares + i_housing_gain 
  label variable i_kg "realized domestic and foreign capital gains (equities + housing)"
  gen i_pension= i_pension_folketrygd + i_pension_other + i_f_pension
  label variable i_pension "pension income domestic and foreign(= pension distributions)"
  gen i_inc= i_wage + i_int + i_div + i_pension + i_business + i_housing + i_otherfin
  label variable i_inc "total taxable income excluding KG"
 
*define income with capital gains (where capital gains are set to zero when negative)*
  gen i_inckg = i_inc + max(i_kg,0) 
  label var i_inckg "total income incl. KG"
 
* labor + mixed income 
  gen i_linc=i_wage + i_pension + i_business
  label var i_linc "total incme from labor and self-employed business" 
  rename L_1_5_3 i_inheritance
  label variable i_inheritance "gift and inheritances received during the year"
	
* compute disclosed income by subtracting stated values from final assessed values*
  gen di_income = i_alminnelig_inntekt - P_3_4 
  label var di_income "disclosed alminnelig inntekt, tax statement"
  gen di_f_capinc=i_f_capinc-P_UTL_KAPINNT
  label var di_f_capinc "disclosed foreign cpaital income"

  keep ID year i_* di_* 
  compress
  sort ID
  d, fullname
  sum
save  $data\income_`yr'.dta, replace
}

*****
foreach yr in 01 02    {
use $source\dsb_20`yr'.dta, clear
  rename FNR_NN ID
  rename aar year
  drop if L_3_4==. & L_4_9==. & L_UTL_KAPINTT==.
  gen L_2_7_9=L_NARINGSINNT 
  sort ID
  duplicates tag ID , generate(dupl)
  tab dupl
save $temp\temp1.dta, replace
  keep if dupl>0
  rename L_4_9 L_NETTOFORMUE
  replace L_NETTOFORMUE=0 if L_NETTOFORMUE==. 
  sort ID L_NETTOFORMUE
  duplicates drop ID L_NETTOFORMUE, force
  sort ID L_NETTOFORMUE
save $temp\temp2dupl.dta, replace
  keep ID L_NETTOFORMUE
  collapse (max) L_NETTOFORMUE , by(ID)
  sort ID L_NETTOFORMUE
  merge ID L_NETTOFORMUE using $temp\temp2dupl.dta
  keep if _m==3
  drop _m dupl
save $temp\temp3.dta, replace
use $temp\temp1.dta, clear
  drop if dupl>0
  drop dupl
  append using $temp\temp3.dta
  sort ID
  duplicates report ID
 
* Add on variables that were missing or incomplete
  merge 1:1 ID using $source\add_pension_`yr'.dta
  drop if _m==2
  drop _m
  merge 1:1 ID using $source\add_div_`yr'.dta
  drop if _m==2
  drop _m
  sort ID
 
  rename L_2_1_6 i_wage
  rename L_3_1_1 i_interests
  rename OBLINNT_INNL i_bonds
  rename ANDRE_KAPINNT i_otherfin
  rename L_3_1_5 i_kg_shares 
  rename L_2_8_4 i_housing_gain 
  rename L_3_4 i_alminnelig_inntekt
  label var year "year"
  label var ID "personal identifyer"
  label var i_alminnelig_inntekt "-alminnelig- income net of all deductions"
  label var i_interests "domestic interest income"
  label var i_kg_shares "domestic taxable realized capital gains from shares"
  label var i_bonds "domestic income from bonds"
  label var i_otherfin  "other financial income"
  label var i_housing_gain  "domestic captial gains realized housing"
  label var i_pension_folketrygd  "domestic pension income from public pension - folketrygden"
  label var i_pension_other  "domestic other pension income, not public pension"

global incvars " L_3_1_4 L_UTL_KAPINTT P_UTL_KAPINNT i_div_add i_pension_folketrygd i_pension_other i_wage i_interests i_bonds i_otherfin i_kg_shares   i_housing_gain  i_alminnelig_inntekt   L_1_5_3  P_3_4  L_3_3_6 L_2_7_9  " 
 foreach var of global incvars {
  replace `var'=0 if `var'==.
 }

* domestic variables
  gen i_div=L_3_1_4+i_div_add
  drop i_div_add
  rename L_2_7_9 i_business
  label variable i_div "domestic dividend income"
  label variable i_business "business income: income from unincorporated businesses + farm + forest"
  label variable i_housing "Housing rents, net inocome from housing"
  label variable i_wage "domestic wage income"
  
* foreign variables
  rename L_UTL_KAPINTT i_f_capinc
  gen i_f_inc=i_f_capinc
  label variable i_f_inc "total foreign income"
  label variable i_f_capinc "total foreign capital income"

* Create income variables, domestic+foreign income 
* Only have total foreign capipital income befoer 2006, so variables will not be consistent over time. 
* i_int is defined as indlucing interest income from 2006 and ownard, but befoere, it also includes all kinds of capital incomes
  gen i_int=i_interests + i_bonds + i_f_capinc
  label variable i_int "interest income: interest from domestic deposits + bonds"
  gen i_kg= i_kg_shares + i_housing_gain 
  label variable i_kg "realized domestic and foreign capital gains (equities + housing)"

*gen i_pension= i_pension_folketrygd + i_pension_other + i_f_pension
  gen i_pension= i_pension_folketrygd + i_pension_other 
  label variable i_pension "pension income domestic and foreign(= pension distributions)"
  gen i_inc= i_wage + i_int + i_div + i_pension + i_business + i_housing + i_otherfin
  label variable i_inc "total taxable income excluding KG"
 
*define income with capital gains (where capital gains are set to zero when negative)*
  gen i_inckg = i_inc + max(i_kg,0) 
  label var i_inckg "total income incl. KG"
 
* labor + mixed income 
  gen i_linc=i_wage + i_pension + i_business
  label var i_linc "total incme from labor and self-employed business" 
  rename L_1_5_3 i_inheritance
  label variable i_inheritance "gift and inheritances received during the year"
	
* compute disclosed income by subtracting stated values from final assessed values
  gen di_income = i_alminnelig_inntekt - P_3_4 
  label var di_income "disclosed alminnelig inntekt, tax statement"
  gen di_f_capinc=i_f_capinc-P_UTL_KAPINNT
  label var di_f_capinc "disclosed foreign cpaital income"

  keep ID year i_* di_*
  compress
  sort ID
  d, fullname
  sum
save  $data\income_`yr'.dta, replace
}

**************************************************************
log close
clear 
 
 
  
