clear
set more off


	global prog   "\\...\CLEAN\prog"
	global source "\\...\source_data\no"
	global data   "\\...\CLEAN\data"
    global temp   "\\...\data\no-backup"
	// Ado file directory
	global ado_dir "\\...\data\durable\norway\prog\ado"
	sysdir set PERSONAL "$ado_dir"

cap log close
log using $prog\makedata2_wealthCLEAN.log, replace
 
/************************************************************************************
*
* Computes wealth at market value in Norway
* And adds final wealth variables for voluntary disclosers whose cases have been closed 
*   (with decision) after initial data delivery
* 
* Part A cleans taxable wealth data
* Part B constructs market value wealth from cleaned taxable wealth data  
* 
************************************************************************************/


************************************************************************
*** PART A: CLEANS TAXABLE WEALTH DATA ***
************************************************************************

foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13  {


	if `yr' <   50 local year = 20`yr' 
	if `yr' >=  50 local year = 19`yr'
	di "RUNNING YEAR `year'" 	

* Import raw taxable wealth variables & clean
	use $source\wealth_`yr'.dta, clear
	qui gen year = `year'
	duplicates report ID
	sort ID netwealth
	by ID: keep if _n == _N
	sort ID
	merge 1:1 ID using $source\tax_`yr'.dta, keep(match master) nogen
	cap drop tax_all_blurred
   cap drop tax_income_blurred 
	cap drop tax_wealth_blurred
	foreach var of varlist a_* d_* p_* *wealth* *tax* {
		qui replace `var' = 0 if `var' == .
	  }

* Add discrepancy between a_nonvps_total and a_nonvps_sum to a_shares_nonreg before 2009
	if `yr' < 09 {
		qui rename a_shares_nonreg a_shares_nonreg_bad
		qui gen    a_shares_nonreg = a_shares_nonreg + abs(a_nonvps_total - a_nonvps_sum)
		qui drop   a_shares_nonreg_bad
	}

* Add discrepancy between a_total and sum of wealth components to leisure housing before 2009
	#delimit;
		qui egen sumofpart = rsum(a_housing_primary a_housing_leisure a_f_housing a_business_prop a_business_other a_shares_reg a_shares_nonreg a_bondfunds a_foreignshares a_f_shares a_cash	a_deposits a_bonds_reg a_f_bonds a_f_deposits a_pension a_movables);
		#delimit cr
		
	if `yr' < 09 {
		qui rename a_housing_leisure a_housing_leisure_bad
		qui gen a_housing_leisure = a_housing_leisure + a_total - sumofpart
		qui replace a_housing_leisure = max(0, a_housing_leisure)
		drop a_housing_leisure_bad
		
		* Make discrepancy variable for all years 
        gen a_discrepancy = a_total - sumofpart
	}
     if `yr' > 08 {
    gen a_discrepancy = .
	}
* Label taxable wealth variables	
	cap label var year "year"
	cap label var ID "ID"
	cap label var a_housing_primary "tax value of domestic primary + secondary homes"
	cap label var a_housing_leisure "tax value of leisure house"
	cap label var a_f_housing "tax value of foreign real estate"
	cap label var a_business_prop "tax value of business property"
	cap label var a_shares_reg "tax value of Norwegian shares registered in Norway"
	cap label var a_shares_nonreg "tax value of Norwegian shares not registered in Norway"
	cap label var a_bondfunds "tax value of shares in bonds funds"
	cap label var a_foreignshares "tax value of foreign shares registered in Norway"
	cap label var a_f_shares "tax value of foreign shares not registered in Norway + held offshores"
	cap label var a_cash "tax value of cash"
	cap label var a_deposits "tax value of bank deposits"
	cap label var a_bonds_reg "tax value of registered bonds"
	cap label var a_f_bonds "tax value of bonds held in foreign countries"
	cap label var a_f_deposits "tax value of deposits held in foreign banks"
	cap label var a_pension "tax value of pension assets"
	cap label var a_movables "tax value of movable property"
	cap label var a_discrepancy "difference btw a_total sum asset composition parts"
	cap label var d_debt "tax value of debt"
	cap label var netwealth "tax value of net wealth"
	cap label var tax_wealth "assessed taxes on wealth (municipality and state)"
	cap label var tax_income "assessed taxes on 'ordinary income' (municipality, region and felles)"
	cap label var tax_all "sum of all assessed taxes"
	cap label var p_netwealth "claimed value of net wealth"
	cap label var a_pf_housing "claimed value of foreign housing"
	cap label var a_pf_shares "claimed value of foreign shares"
	cap label var a_pf_bonds "claimed value of foreign bonds"
	cap label var a_pf_deposits "claimed value of foreign deposits"
	// following variables only exist in 2008 and before.
	cap label var a_vps_total "tax value of all registered securities"
	cap label var a_nonvps_total "tax value of all nonregistered securities"
	cap label var a_vps_sum "tax value of the sum of all categories of registered securities"
	cap label var a_nonvps_sum "tax value of the sum of all categories of non-registered securities" 
	// following variables only exist since 2009
	cap label var a_foreignbondsfunds "tax value of shares in funds holding foreign bonds"
	cap label var a_f_business "tax value of foreign business property"
	cap label var a_pf_business "claimed value of foreign property"

* Correct final wealth variables for voluntary disclosers whose cases have been closed (with decision) after our initial data delivery
* These data are prepared in makedata0_disclosersCLEAN.do
	merge 1:1 ID using $temp\corr_`yr'.dta, keep(match master)
	if _m == 3 {
		foreach var in f_housing f_business f_shares f_bonds f_deposits  {
			qui replace a_`var' = a_p`var' + diff_`var' // diff = difference between claimed (paastand) and assessed (ligning) variables
		}
		qui replace diff_nettoformue = 0 if diff_nettoformue == .
		qui gen netwealth_updated = p_netwealth + diff_nettoformue
		assert netwealth_updated >= netwealth
		qui replace netwealth = netwealth_updated
		qui drop netwealth_updated
	}
	qui drop diff_* _m

* Construct da* = taxed wealth minus claimed wealth (= wealth disclosed + other discrepancies)
	cap drop da_* 
	qui gen da_wealth = netwealth - p_netwealth
	label variable da_wealth "disclosed wealth"
	qui gen da_housing = a_f_housing - a_pf_housing
	label variable da_housing "disclosed offshore housing wealth"
	qui gen da_fixed = a_f_bonds + a_f_deposits - a_pf_bonds -  a_pf_deposits
	label variable da_fixed "disclosed offshore deposits and bonds"
	qui gen da_equity = a_f_shares - a_pf_shares
	label variable da_equity "disclosed offshore equity wealth"
	qui cap gen da_business = a_f_business -  a_pf_business
	cap label variable da_business "disclosed offshore business assets"
 
	compress
	sort ID
	save $data\WEALTH_`yr'.dta, replace
}


************************************************************************
 *** PART B: MATCH TO MACRO TOTALS ***
************************************************************************
 
 foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13  {

	if `yr' <   50 local year = 20`yr' 
	if `yr' >=  50 local year = 19`yr'
	di "RUNNING YEAR `year'" 

* Load macro parameters 
	insheet using "\\...\data\durable\norway\data\parameters.txt", clear names
	keep if year == `year'
	foreach var of varlist _all {
		local `var' = `var'
	}

use $data\WEALTH_`yr'.dta, clear

* Housing
	cap drop ma_housing_condo
	// Condo housing (primary + secondary): uniform multiplicative scale up to macro total	
		rename a_housing_primary a_housing_condo
		qui su a_housing_condo, meanonly
		local scale_condo = `ttcondo' / r(sum)
  		di "SCALE UP FACTOR FOR CONDO HOUSING IN `year' = `scale_condo'"
		qui gen ma_housing_condo = a_housing_condo * `scale_condo'
		qui replace ma_housing_condo = 0 if ma_housing_condo == .
		label variable ma_housing_condo "Market value domestic primary + secondary homes"
	// For foreign homes, assume tax value=0.4 of market value (same assumption as for NA aggregate)
		cap drop ma_f_housing
		qui gen ma_f_housing = a_f_housing / 0.4
		label variable ma_f_housing "Market-value foreign housing wealth"
	// For leisure homes, assume 10% of market value primary house (same assumption as for NA aggregate)
		cap drop ma_housing_leisure
		qui gen ma_housing_leisure = 0.1 * ma_housing_condo 
		label variable ma_housing_leisure "Market-value leisure home"
		cap drop ma_housing
		egen ma_housing = rsum(ma_housing_condo ma_housing_leisure ma_f_housing)
		label variable ma_housing "Housing wealth at market value"
	// Small discrepancy between macro and micro foreign housing, scale here 	
		qui su ma_housing, meanonly
		local scale_house = `tthouse' / r(sum)
		di "RESIDUAL SCALE UP FACTOR FOR TOTAL HOUSING ASSETS IN `year' = `scale_house'"
		qui replace ma_housing = ma_housing * `scale_house'		
		qui su ma_housing, meanonly
		local total = round(r(sum) / 1e9)
		di "TOTAL MARKET VALUE HOUSING IN YEAR `year': `total' BN NOK"
		assert `total' == round(`tthouse' / 1e9)

* Business assets
	cap drop a_business 
	if `year' >= 2009 qui egen a_business = rsum(a_business_prop a_business_other a_f_business)
	if `year' <  2009 qui egen a_business = rsum(a_business_prop a_business_other)
	label variable a_business "Tax-value business & other assets"
	qui su a_business, meanonly
	local scale_biz = `ttbiz' / r(sum)
	di "SCALE UP FACTOR FOR BUSINESS ASSETS IN `year' = `scale_biz'"
	cap drop ma_business 
	qui gen ma_business = a_business * `scale_biz'
	label variable ma_business "Market-value business & other assets"
	qui su ma_business, meanonly
	local total = round(r(sum) / 1e9)
	di "TOTAL MARKET VALUE BUSINESS IN YEAR `year': `total' BN NOK"
	assert `total' == round(`ttbiz' / 1e9)

* Equities
	// Market value of listed shares (domestic and foreign taxed the same)
		foreach var in a_shares_reg  a_foreignshares {
			cap drop m`var'
			if `yr'< 05 | `yr' > 07 qui gen m`var' = `var'       
			if `yr'== 05				qui gen m`var' = `var'/ 0.65 
			if `yr'== 06				qui gen m`var' = `var'/ 0.8  
			if `yr'== 07				qui gen m`var' = `var'/ 0.85
			qui replace  m`var' = 0 if m`var' == .
		}
	// Market value of unlisted shares (domestic and foreign taxed the same)
		foreach var in a_shares_nonreg a_f_shares {
			cap drop m`var'
			if `yr' <  06 			qui gen m`var'=`var' / 0.65 
			if `yr' == 06 			qui gen m`var'=`var' / 0.8 
			if `yr' == 07 			qui gen m`var'=`var' / 0.85 
			if `yr' >  07 			qui gen m`var'=`var' 
			qui replace  m`var' = 0 if m`var' == .
		}
		cap drop ma_f_equity
		if `yr' >= 09 qui egen ma_f_equity = rsum(ma_foreignshares a_foreignbondsfunds ma_f_shares)
		if `yr' <  09 qui egen ma_f_equity = rsum(ma_foreignshares  ma_f_shares)
		label variable ma_f_equity "Market value foreign shares (listed + unlisted + funds)"
		cap drop ma_equity 
		qui egen ma_equity = rsum(ma_shares_reg ma_shares_nonreg a_bondfunds ma_f_equity)
		label variable ma_equity "Market value shares (listed + unlisted + funds)"
	// Scale up to macro total, very small residual
		qui su ma_equity, meanonly
		local scale_eq = `ttequity' / r(sum)
		di "SCALE UP FACTOR FOR EQUITIES IN `year' = `scale_eq'"
		qui replace ma_equity = ma_equity * `scale_eq'
		qui su ma_equity, meanonly
		local total = round(r(sum) / 1e9)
		di "TOTAL MARKET VALUE EQUITIES IN YEAR `year': `total' BN NOK"
		assert `total' == round(`ttequity' / 1e9)


* Fixed-income claims 
	cap drop ma_f_fix
	qui egen ma_f_fix = rsum(a_f_bonds a_f_deposits)
	label variable ma_f_fix "Market-value foreign deposits & bonds"
	cap drop ma_fix 
	qui egen ma_fix = rsum(a_cash a_deposits a_bonds_reg ma_f_fix)
	label variable ma_fix "Market-value fixed-income claims"
	qui su ma_fix, meanonly
	local scale_fix = `ttfix' / r(sum)
	di "SCALE UP FACTOR FOR FIXED-INCOME CLAIMS IN `year' = `scale_fix'"
	qui replace ma_fix = ma_fix * `scale_fix'
	qui su ma_fix, meanonly
	local total = round(r(sum) / 1e9)
	di "TOTAL MARKET VALUE FIXED INCOME CLAIMS IN YEAR `year': `total' BN NOK"
	assert `total' == round(`ttfix' / 1e9)

* Pension wealth
* 40% proportional to wages; 60% proportional to funded pension distributions for retirees
* Assumes all wage earners have pension wealth (occupational pension is quasi-mandatory)
	sort ID 	
	merge 1:1 ID using $data\income_`yr'.dta, keepusing(i_wage i_pension_other) keep(match master) nogen
	merge 1:1 ID using $data\perskar_`yr'.dta, keepusing(ind_age) keep(match master) nogen
	qui su i_wage if ind_age >= 20 & ind_age < 40 & i_wage != . & i_wage > 0, meanonly
	cap drop ma_pension
	qui gen ma_pension = i_wage * 0.1 * `ttpension' / r(sum) if ind_age >= 20 & ind_age < 40 & i_wage != . & i_wage > 0
	qui su i_wage if ind_age >= 40 & ind_age != . & i_wage != . & i_wage > 0, meanonly
	qui replace ma_pension = i_wage * 0.3 * `ttpension' / r(sum) if ind_age >= 40 & ind_age != . & i_wage != . & i_wage > 0
	qui su i_pension_other if (i_wage == . | i_wage == 0) & i_pension_other != . & i_pension_other > 0, meanonly
	qui replace ma_pension = i_pension_other * 0.6 * `ttpension' / r(sum) if (i_wage == . | i_wage == 0) & i_pension_other > 0 & i_pension_other != .
	qui replace ma_pension = 0 if ma_pension == .
	qui drop i_wage i_pension_other ind_age
	label variable ma_pension "Market value pension wealth"
	qui su ma_pension, meanonly
	local total = round(r(sum) / 1e9)
	di "TOTAL MARKET VALUE PENSION WEALTH IN YEAR `year': `total' BN NOK"
	assert `total' == round(`ttpension' / 1e9)	

* Debt (saved with minus sign)
	cap drop md_debt
	qui gen md_debt = - d_debt
	label variable md_debt "Debt (saved with minus sign)"
	qui replace md_debt = 0 if md_debt == .
	qui su md_debt, meanonly
	local scale_debt = -`ttdebt' / r(sum)
	di "SCALE UP FACTOR FOR DEBT IN `year' = `scale_debt'"
	assert `scale_debt' > 0
	qui replace md_debt = md_debt * `scale_debt'
	qui su md_debt, meanonly
	local total = round(r(sum) / 1e9)
	di "TOTAL MARKET VALUE DEBT IN YEAR `year': `total'BN  NOK"
	assert `total' == - round(`ttdebt' / 1e9)		

* Net wealth
	cap drop ma_f_wealth
	if `yr' >= 09 qui egen ma_f_wealth = rsum(ma_f_housing ma_f_fix ma_f_equity a_f_business)
	if `yr' <  09 qui egen ma_f_wealth = rsum(ma_f_housing ma_f_fix ma_f_equity)
	label var ma_f_wealth "Market value foreign wealth"
	cap drop mwealth
	qui egen mwealth = rsum(ma_housing ma_fix ma_equity ma_business ma_pension md_debt)
	label variable mwealth "Net wealth at market value"
	qui su mwealth, meanonly
	local total = round(r(sum) / 1e9)
	di "TOTAL MARKET VALUE NET WEALTH IN YEAR `year': `total' BN NOK"
	assert `total' == round(`ttwealth' / 1e9)
	qui rename netwealth taxwealth
	
	compress
	sort ID
	d, fullname
   	sum
	save $data\WEALTH_`yr'.dta, replace
}

 
* For supplementary, alternative wealth computations:
	* do $prog\capitalize-nonvps.do // capitalize non VPS profits to compute distribution of non-VPS equity
	* do $prog\improve-housing-post2010.do // different scale up ratios for primary vs. secondary housing


* Check: wealth distribution indiv	
	foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13 {	
        *import the age variable constructed in makedata1_individual_caracteristicCLEAN.do
	    use $data\perskar_`yr'.dta, clear
	    keep ID ind_age
	    save $temp\age_`yr'.dta, replace
	
		use ID  mwealth ma_housing ma_fix ma_equity ma_business ma_pension md_debt using $data\WEALTH_`yr'.dta, clear
		merge 1:1 ID using $temp\age_`yr'.dta
		  keep if _m==3
		drop _m
		
		keep if ind_age >= 20
		qui gen net_housing = ma_housing + md_debt
		shcomp mwealth ma_equity ma_fix net_housing ma_business ma_pension, matname(mwealth`yr')
				mat mwealth`yr'  = (`yr', mwealth`yr')
				mat mwealth   = (nullmat(mwealth)  \ mwealth`yr')
				di "TOP WEALTH SHARE AND THEIR COMPOSITION (MWEALTH)"
				mat list mwealth
	}
	clear
	svmat mwealth, names(col)
	qui compress
	export excel using "$data\wealth_distrib_indiv", first(var) replace


cap log close
clear 
