
clear
set more off

	global prog   "\\...\CLEAN\prog"
	global source "\\...\source_data\no"
	global data   "\\...\CLEAN\data"
    global temp   "\\...\data\no-backup"
	global results "\\...\CLEAN\data"

cap log close
log using $prog\makedata7_profits_ownersCLEAN.log, replace

/********************************************************************************
* check aggregate profits, aggregate attributed retained earnings, 
* that this corresponds to aggregate sums from Statistics Norway and from the 
* other work on income, by year
*
* Make estimat for average retained earnings in the firm, to estimate the value
* of the firm on indiviudal level. Make crude measure of profits net of dividends 
* in order not to double count profits in the chain of firms, as one firm's 
* dividend payments is another firms income and affects profits, and then just 
* taking the sum of profits across all firms in the chain could potentially hugely 
* overestimate true indirectly owned profits, if dividends are distributed
*
* have ownerhsip info from 2004 and onward, and accounting data until 2012.
********************************************************************************/

* Make vps_indicator
    foreach yr in 04 05 06 07 08 09 10 11 12 {
    use $source\AR_selskap.dta, clear
    keep if aar==20`yr'
    rename ORGNR_NN as_orgnr
    replace vps=0 if vps==.
    collapse (max) vps, by(as_orgnr)
    tab vps, m
    sort as_orgnr
    save  $temp\vps`yr'.dta, replace
    }

/******************************************************************************** 
* #1: for each firm and year find how much dividends they distribute to other firms.	    	
********************************************************************************/ 

* Find total dividends distributed by corporations to other corporations and to individuals, by year
    use $source\ar_aksjonaer2.dta, clear
    rename AKSJ_ORGNR_NN firmowner
	rename AKSJ_FNR_NN ID
	rename UTB_BELOP div_all
	rename aar year
	rename ORGNR_NN as_orgnr
	replace div_all=0 if div_all==.	
    gen div_firms=div_all if firmowner!=.
	replace div_firms=0 if div_firms==.
    gen div_ind=div_all if ID!=.
	replace div_ind=0 if ID==.
	replace div_ind=0 if ID==0
	sort as_orgnr year
	collapse (sum) div_firms div_ind div_all, by(as_orgnr year)
	sort as_orgnr year
	compress
	sum
	bysort year: sum div_firms div_ind div_all, det
    save $temp\firmdisv.dta, replace
	
   *make annual data sets with dividends to other firms
    foreach yr in 04 05 06 07 08 09 10 11 12  {
    use $temp\firmdisv.dta, clear
	keep if year==20`yr'
	drop year 
	sort as_orgnr
    save $temp\firmdiv_`yr'.dta, replace
	}
	
/******************************************************************************** 
* #2: for each firm and year compute profits after dividends to to other firms 
      (in order to avoid double counting of profits, as one firm's dividend payments
	  goes into the recieving firm's profits)	  
********************************************************************************/

   foreach yr in  04 05 06 07 08 09 10 11 12 {
   use $data\corporate_info_`yr'.dta, clear
   gen year=20`yr'
   keep as_orgnr year firm_profits_beforetax firm_profits_aftertax firm_operating_income firm_operating_costs
   sort as_orgnr
   duplicates report as_orgnr
   drop if firm_profits_beforetax==. | firm_profits_aftertax==. | firm_operating_income==. | firm_operating_costs==.
   gen firm_operating_profits=firm_operating_income-firm_operating_costs
   label var firm_operating_profits "operating profits = operagint income - operating costs"
   
   *add info on dividends to other firms
   merge 1:1 as_orgnr using $temp\firmdiv_`yr'.dta
   *only keep firms for which we have dividend info (==ownership) and corporate info, require that to be in the sample
   keep if _m==3
   drop _m
   *generate change retained proftis variable, as after-tax profits  - dividends to other firms
   gen firm_retprofs = firm_profits_aftertax - div_firms
   label var firm_retprofs "aftertx profits minus distr dividends to other firms"
   replace firm_retprofs=0 if firm_retprofs==.
   *** also generate change retained proftis variable, as after-tax profits  - ALL dividends 
   gen firm_retprofs_all = firm_profits_aftertax - div_all
   label var firm_retprofs_all "aftertx profits minus ALL distr dividends"
   replace firm_retprofs_all=0 if firm_retprofs_all==. 
   sort as_orgnr 
   
   *add on vps-info
   merge 1:1 as_orgnr using $temp\vps`yr'.dta
   keep if _m==3
   drop _m
   sum
   save $temp\y_`yr'.dta, replace
   
   keep if vps==1
   tab year
   collapse (mean) year (sum) firm_operating_income firm_operating_costs firm_operating_profits firm_retprofs firm_profits_beforetax firm_profits_aftertax  div_firms  div_ind div_all firm_retprofs_all
   l
   save $temp\agg_vps_`yr'.dta, replace
   
   use $temp\y_`yr'.dta, clear
   keep if vps==0
   tab year 
   collapse (mean) year (sum) firm_operating_income firm_operating_costs firm_operating_profits firm_retprofs firm_profits_beforetax firm_profits_aftertax  div_firms  div_ind div_all firm_retprofs_all
   l
   save $temp\agg_`yr'.dta, replace
   }
      **********
   *how much firm level profits and operating income are attributed to individuals for all firms and all years
         foreach yr in  04 05 06 07 08 09 10 11 12 {
          use $data\total_ownshares`yr'_ind.dta, clear
          keep ID as_orgnr total_ownshare 
		  drop if ID==.
          drop if total_ownshare==.
          drop if total_ownshare==0
          drop if ID==0
          sort as_orgnr
          merge n:1 as_orgnr using  $temp\y_`yr'.dta
          keep if _m==3
          drop _m
          count
          gen share_retprofs=firm_retprofs*total_ownshare
		  gen share_retprofs_all=firm_retprofs_all*total_ownshare
		  gen share_operating_income=firm_operating_income*total_ownshare
		  gen share_operating_profits=firm_operating_profits*total_ownshare
		  
		  sum share_retprofs share_retprofs_all share_operating*, det
          tab year
		  save $temp\b_`yr'.dta, replace
		  *****
		  sort as_orgnr 
		  collapse (sum) total_ownshare share_retprofs_all firm_retprofs_all share_operating_income share_operating_profits, by(as_orgnr)	  
		  gen negative=(firm_retprofs_all<0)
		  sum
		  sort negative
		  tab negative
		  by negative: sum  total_ownshare share_retprofs_all firm_retprofs_all share_operating_income share_operating_profits, det
		  collapse (sum) share_retprofs_all share_operating_income share_operating_profits (mean) total_ownshare, by(negative)
		  l
		  *****
		  *find the total retained profits and attributed to individuals, vps-firms
		  use $temp\b_`yr'.dta, clear
		  keep if vps==0
		  collapse  (sum) share_retprofs share_retprofs_all share_operating_income share_operating_profits 
		  gen year=20`yr'
          l
		  sort year
		  merge 1:1 year using $temp\agg_`yr'.dta
		  keep if _m==3
		  drop _m
		  l
		  save $temp\agg_`yr'.dta, replace
          *****
		  * find the total retained profits and attributed to individuals, NON-vps-firms
		  use $temp\b_`yr'.dta, clear
		  keep if vps==1
		  collapse  (sum) share_retprofs share_retprofs_all share_operating_income share_operating_profits 
		  gen year=20`yr'
          l
		  sort year
		  merge 1:1 year using $temp\agg_vps_`yr'.dta
		  keep if _m==3
		  drop _m
		  l
		  save $temp\agg_vps_`yr'.dta, replace	  
          }
		
		use $temp\agg_04.dta, clear
		foreach yr in   05 06 07 08 09 10 11 12 {
		append using $temp\agg_`yr'.dta
		}
		sort year
        export excel using $results\exploreprofits.xls, firstrow(variables) sheet("Totals_allfirms_NONvps") sheetreplace
		l
 	    use $temp\agg_vps_04.dta, clear
		foreach yr in   05 06 07 08 09 10  11 12 {
		append using $temp\agg_vps_`yr'.dta
		}
		sort year
        export excel using $results\exploreprofits.xls, firstrow(variables) sheet("Totals_allfirms_vps") sheetreplace
		l
	
/********************************************************************************
Allocate operating profits of non-VPS firms to individual shareholder
dataset with ID and operating_profits_nonvps = operating profits of non-VPS firms allocated to each individual
********************************************************************************/

	  foreach yr in  04 05 06 07 08 09 10 11 12 {
		use $temp\b_`yr'.dta, clear
		keep ID share_operating_profits share_operating_income as_orgnr vps
		* only interested in non-vps firms, and total operating profits and income allocated to individuals
		keep if vps==0
		collapse (sum) share_operating_profits share_operating_income, by(ID)
		rename share_operating_profits operating_profits_nonvps
		rename share_operating_income operating_income_nonvps
		label var operating_profits_nonvps "sum operating profits of non-VPS firms allocated to each ID"
		label var operating_income_nonvps "sum operating income of non-VPS firms allocated to each ID"
		sort ID
		save $data\operating_nonvps_`yr', replace
		
		sum operating_profits_nonvps operating_income_nonvps, det
		collapse (sum) operating_profits_nonvps operating_income_nonvps
		gen year=20`yr'
		}
********************************************************************************
   clear
   log close
