*! Bring HSBC, Panama, and disclosers dummies in 2006 Scandinavian appended g-perc dataset 

* Import HSBC evaders in 2006 file
	use "$root/WorkScandinavia/temp/appended06.dta", clear
	saveold $root/WorkScandinavia/Output/evasion2006.dta, replace
	foreach country in NOR SWE DNK {
		if "`country'" == "NOR" import excel using "$root/WorkNorway/HSBCListNorway/hsbc_skatt.xlsx", sh(ToStata) first clear
		if "`country'" == "SWE" import excel using "$root/WorkSweden/HSBCSweden/hsbc_scb.xlsx", sh(ToStata) first clear
		if "`country'" == "DNK" import excel using "$root/WorkDenmark/HSBC/hsbc_soren.xlsx", sh(ToStata) first clear
		if "`country'" == "NOR" { // use 2007 distribution for Scandinavia 
			drop nb_hsbc nb_hsbc_pos amt_hsbc
			rename nb_hsbc_07 		nb_hsbc
			rename nb_hsbc_pos_07 	nb_hsbc_pos
			rename amt_hsbc_07 		amt_hsbc
			rename se_amt_hsbc_07	se_amt_hsbc
		}
		gen ctry = "`country'"
		gen year = 2006
		if "`country'" == "NOR" | "`country'" == "DNK" {
			expand  10, gen(new)
			drop if new == 1 & ptile_w >= 90000 & ptile_w < 99990
			sort ptile_w
			replace ptile_w = 1000 * (_n - 1) if ptile_w < 90000 
			sort ptile_w new
			replace ptile_w = ptile_w[_n-1] + 1 if ptile_w >= 99990 & new == 1
			drop new
			replace nb_hsbc = nb_hsbc / 10 		   if ptile_w < 90000 | ptile_w >= 99990
			replace nb_hsbc_pos = nb_hsbc_pos / 10 if ptile_w < 90000 | ptile_w >= 99990
			merge 1:1 ctry year ptile_w using $root/WorkScandinavia/Output/evasion2006.dta, nogen
			saveold $root/WorkScandinavia/Output/evasion2006.dta, replace
		}
		if "`country'" == "SWE" {
			expand  10, gen(new)
			drop if new == 1 & ptile_w >= 90000 
			sort ptile_w
			replace ptile_w = 1000 * (_n - 1) if ptile_w < 90000 
			drop new
			expand  5 if ptile_w >= 99995, gen(new)
			sort ptile_w new
			replace ptile_w = ptile_w[_n-1] + 1 if ptile_w >= 99995 & new == 1
			drop new
			replace nb_hsbc = nb_hsbc / 10 		   if ptile_w < 90000
			replace nb_hsbc = nb_hsbc / 5 		   if ptile_w >= 99995
			replace nb_hsbc_pos = nb_hsbc_pos / 10 if ptile_w < 90000
			replace nb_hsbc_pos = nb_hsbc_pos / 5 if ptile_w >= 99995
			merge 1:1 ctry year ptile_w using $root/WorkScandinavia/Output/evasion2006.dta, nogen
			saveold $root/WorkScandinavia/Output/evasion2006.dta, replace
		} 
		replace nb_hsbc = 0 if nb_hsbc == .
		replace nb_hsbc_pos = 0 if nb_hsbc_pos == .
		saveold $root/WorkScandinavia/Output/evasion2006.dta, replace
	}

* Import Norwegian disclosers in 2006 file
	use "$root/WorkNorway/SmallFiles/small06hhold.dta", clear
	replace ptile_w = round(1000 * ptile_w)
	replace vd_evader = round(vd_evader * weight)
	replace vd_case_dropped = round(vd_evader * vd_case_dropped)
	gen nb_disc = vd_evader - vd_case_dropped
	rename disclosed_wealth07C disclosed_wealth
		gen tot_hidden = disclosed_wealth * vd_evader
	 	qui su tot_hidden
	 	local tot_hidden = round(r(sum)/1e9, .1)
	 	di "TOTAL HIDDEN WEALTH = `tot_hidden' BILLION NOK"
	gen ctry = "NOR" 
	keep ctry year ptile_w vd_evader vd_case_dropped nb_disc disclosed_wealth
	merge 1:1 ctry year ptile_w using $root/WorkScandinavia/Output/evasion2006.dta, nogen
	saveold $root/WorkScandinavia/Output/evasion2006.dta, replace	


* Import Swedish discloers in 2006 file
	import excel using "$root/WorkSweden/Disclosers/RawData/disclosers_scb.xlsx", sh(ToStata) first clear	
		gen ctry = "SWE"
		gen year = 2006
		expand  10, gen(new)
		drop if new == 1 & ptile_w >= 90000 & ptile_w < 99990
		sort ptile_w
		replace ptile_w = 1000 * (_n - 1) if ptile_w < 90000 
		sort ptile_w new
		replace ptile_w = ptile_w[_n-1] + 1 if ptile_w >= 99990 & new == 1
		drop new
		replace nb_disc = nb_disc / 10 		   if ptile_w < 90000 | ptile_w >= 99990
		replace nb_disc_hsbc = nb_disc_hsbc / 10 if ptile_w < 90000 | ptile_w >= 99990
		keep ctry year ptile_w nb_disc*
		merge 1:1 ctry year ptile_w using $root/WorkScandinavia/Output/evasion2006.dta, nogen
		saveold $root/WorkScandinavia/Output/evasion2006.dta, replace


* Import Panama Papers Norway 
	use $root/WorkScandinavia/Output/evasion2006.dta, clear
	gen nb_panama = 0
	saveold $root/WorkScandinavia/Output/evasion2006.dta, replace	

	* Compute factor to convert market-value wealth bins into taxable wealth bins in 2006
		use "$root/WorkNorway/SmallFiles/small06hhold.dta", clear
		gen ratio = taxwealth / mwealth
		replace ptile_w = round(1000 * ptile_w)
		tempfile conversion
		gen ctry = "NOR"
		saveold `conversion'
		use $root/WorkScandinavia/Output/evasion2006.dta, clear
		merge 1:1 ctry ptile_w using `conversion', keepusing(ratio) nogen
		replace ratio = 0.1 if ptile_w < 80000 & ctry == "NOR"
		saveold $root/WorkScandinavia/Output/evasion2006.dta, replace
	* Compute factor to convert taxable wealth 2006 into taxable wealth 2008
		use "$root/WorkNorway/SmallFiles/small06hhold.dta", clear
			qui su taxwealth [fw=weight]
			local total_taxwealth06 = r(sum)
		use "$root/WorkNorway/SmallFiles/small08hhold.dta", clear
			qui su taxwealth [fw=weight]
			local total_taxwealth08 = r(sum)
		local ratio_08_to_06 = `total_taxwealth08' / `total_taxwealth06'
		di "RATIO BETWEEN TAXABLE WEALTH IN 2008 AND TAXABLE WEALTH IN 2006 = `ratio_08_to_06'"
	* Generate 2008 taxable wealth from 2006 market value wealth
		use $root/WorkScandinavia/Output/evasion2006.dta, clear
		gen taxwealth_inf08 = wealth_inf * ratio * `ratio_08_to_06'
		gen taxwealth_sup08 = taxwealth_inf08[_n+1] 
		saveold $root/WorkScandinavia/Output/evasion2006.dta, replace
	* merge Panama Paper dummies	
		import excel using "$root/WorkNorway/PanamaPapersNorway/MergedPanamaWealthNorway.xlsx", sh(ToStata) first clear
		qui de
		local number_panama_obs = r(N)
		mkmat panama_wealth, mat(panama)
		use $root/WorkScandinavia/Output/evasion2006.dta, clear	
		local ii = 1
		while `ii' <= `number_panama_obs' {
			replace nb_panama = nb_panama + 1 if panama[`ii',1]>= taxwealth_inf08 & panama[`ii',1] < taxwealth_sup08 & ctry == "NOR"
			local ii = `ii' + 1	
		}
		drop taxwealth_inf08 taxwealth_sup08 ratio
		saveold $root/WorkScandinavia/Output/evasion2006.dta, replace

* Import Panama Papers Sweden
		import excel using "$root/WorkSweden/Evaders/evaders_mwealth06_hhold.xlsx", sh(ToStata) first clear
		gen ptile_w = round(1000 * gperc)
		gen nb_panama = round(ev_r_panama * nb / 1000)
		gen ctry = "SWE"
		keep ctry ptile_w nb_panama
		merge 1:1 ctry ptile_w using "$root/WorkScandinavia/Output/evasion2006.dta", nogen
		saveold $root/WorkScandinavia/Output/evasion2006.dta, replace
		
