*! Distribution of Panama suspects in Norway, Sweden, and Norway + Sweden

* Outputs results in Appendix F Excel file (formerly panama_by_bin.xls)
	global out_panama "$root/ExcelFiles/AJZ2017AppendixF.xlsx"

*************************************************************************
* Distribution in appended evasion2006 file (only useful for country by country distrib) *
*************************************************************************

* Country-by-country distribution of evaders
	foreach country in NOR SWE  {
		use $root/WorkScandinavia/Output/evasion2006.dta, clear

		keep if ctry == "`country'"
		gen wealth_usd = mwealth / fx
		cap drop group
		gen group = "P0-50"
		replace group = "P50-90"		if  ptile_w >= 50000  	& ptile_w < 90000
		replace group = "P90-95"		if  ptile_w >= 90000  	& ptile_w < 95000
		replace group = "P95-99"		if  ptile_w >= 95000  	& ptile_w < 99000
		replace group = "P99-99.5"		if  ptile_w >= 99000  	& ptile_w < 99500
		replace group = "P99.5-99.9"	if  ptile_w >= 99500 	& ptile_w < 99900
		*replace group = "P99.9-100"		ptile_w >= 99900 	
		replace group = "P99.9-P99.95"	if  ptile_w >= 99900 	& ptile_w < 99950
		*replace group = "P99.95-P100"	if  ptile_w >= 99950
		replace group = "P99.95-P99.99"	if  ptile_w >= 99950	& ptile_w < 99990
		replace group = "P99.99-P100"	if  ptile_w >= 99990	 

		gen tot_wealth_usd =  wealth_usd * weight
		collapse (min) th_usd = wealth_usd (sum) tot_wealth_usd nb_panama weight, by(group)
		gen frac = nb_panama / weight
		replace  tot_wealth_usd = tot_wealth_usd / weight
		rename tot_wealth_usd wealth_usd 
		order group th_usd wealth_usd nb_panama weight frac
		export excel using "$out_panama", sheetmodify first(var) sh(Stata-`country')

	}

*************************************************************************
* Distribution in big Norway + Sweden population-wide file *
*************************************************************************

// We add-back imputed disclosed wealth to Swedish wealth 
// The Norwegian wealth data already include disclosed wealth (because they come from the tax authority)
// while the Swedish data don't (because they come from the stat authority)

* Stats distribution of Panama dummies in pop-wide file for panama_by_bin  (binning 1, from P0-10 up to 99.95)
	use "$root/WorkScandinavia/temp/big_norswe.dta", clear
	replace amt_disc = 0 if amt_disc == . 
	replace wealthusd = wealthusd + amt_disc if ctry=="SWE"
	cap drop rank_scand
	cumul wealthusd [fw=weight], gen(rank_scand)
	cap drop group
	gen group = ""
	foreach i of numlist 0/9 {
		local j = `i' + 1
		replace group = "P`i'0-`j'0" if rank_scand >= `i'/10 & rank_scand < `j'/10
	}	
	replace group = "P90-95" if  rank_scand >= .9 & rank_scand < .95
	replace group = "P95-99" if  rank_scand >= .95  		& rank_scand < .99
	replace group = "P99-99.5" if  rank_scand >= .99  		& rank_scand < .995
	replace group = "P99.5-99.9" if  rank_scand >= .995 		& rank_scand < .999
	replace group = "P99.9-P99.95" if  rank_scand >= .999 		& rank_scand < .9995
	replace group = "P99.95-P100" if rank_scand >= .9995

	gen pop = 1
	collapse (min) th_usd = wealthusd (mean) wealthusd (sum) nb_panama = panama pop [fw = weight], by(group)
	rename pop weight
	gen frac = nb_panama / weight
	order group th_usd wealthusd nb_panama weight frac 
	export excel using "$out_panama", sheetmodify first(var) sh(Stata-fullpop1)

* Stats distribution of Panama dummies in pop-wide file for panama_by_bin (alternative binning, from P0-50 up to P99.99)
	use "$root/WorkScandinavia/temp/big_norswe.dta", clear
	replace amt_disc = 0 if amt_disc == . 
	replace wealthusd = wealthusd + amt_disc if ctry=="SWE"
	cap drop rank_scand
	cumul wealthusd [fw=weight], gen(rank_scand)
	cap drop group
	gen group = "P0-50"
	replace group = "P50-90" if rank_scand >= .5  	& rank_scand < .9
	replace group = "P90-95" if  rank_scand >= .9 & rank_scand < .95
	replace group = "P95-99" if  rank_scand >= .95  		& rank_scand < .99
	replace group = "P99-99.5" if  rank_scand >= .99  		& rank_scand < .995
	replace group = "P99.5-99.9" if  rank_scand >= .995 		& rank_scand < .999
	replace group = "P99.9-P99.95" if  rank_scand >= .999 		& rank_scand < .9995
	replace group = "P99.95-P99.99" if rank_scand >= .9995 & rank_scand < .9999
	replace group = "P99.99-P100" if rank_scand >= .9999

	gen pop = 1
	collapse (min) th_usd = wealthusd (mean) wealthusd (sum) nb_panama = panama pop [fw = weight], by(group)
	rename pop weight
	gen frac = nb_panama / weight
	order group th_usd wealthusd nb_panama weight frac 
	export excel using "$out_panama", sheetmodify first(var) sh(Stata-fullpop2)

