*! Compute wealth and taxable income distribution in Scandinavia in 2006

* Outputs results in Appendix J Excel file (formerly wealth_distrib.xls)
	global out_distrib "$root/ExcelFiles/AJZ2017AppendixJ.xlsx"

* Market value wealth, bins from shcomp
	use "$root/WorkScandinavia/Output/evasion2006.dta", clear
	local yr = 06
	local year = 2006

	foreach ctry in NOR SWE DNK  {
		shcomp mwealth [w=weight] if ctry=="`ctry'", matname(distrib_`ctry')
	}
	gen wealth_usd = mwealth / fx
		shcomp wealth_usd [w=weight], matname(distrib_all)
		mat results = (distrib_all \ distrib_SWE \ distrib_NOR \ distrib_DNK)'
		mat list results
		clear 
		svmat results
		rename results1 Scandinavia
		rename results2 Sweden
		rename results3 Norway
		rename results4 Denmark
		gen group = "All" 
		replace group = "Top 50%" 	 if _n == 2
		replace group = "Top 10%" 	 if _n == 3
		replace group = "Top 5%" 	 if _n == 4
		replace group = "Top 1%" 	 if _n == 5	
		replace group = "Top 0.5%" 	 if _n == 6
		replace group = "Top 0.1%" 	 if _n == 7	
		replace group = "Top 0.01%"  if _n == 8
		order group

	export excel using "$out_distrib", sheetmodify first(var) sh(results_wealth)
	putexcel set  "$out_distrib", modify sh(results_wealth)
	putexcel A12 = ("Scandinavian numbers in this sheet are from appended g-perc file, not Pareto-interpolated pop-wide file") 

* Taxable income (including KG)	and wealth, by decile + zoom at top
	mat drop _all
	local yr = 06
	local year = 2006

	foreach ctry in NOR SWE DNK  {
		use "$root/WorkScandinavia/Output/evasion2006.dta", clear
		keep if ctry == "`ctry'"
		gen group = "."
		foreach i of numlist 0/9 {
			local j = `i' + 1
			replace group = "P`i'0-`j'0" if ptile_w >= `i'*10000 & ptile_w < `j'*10000
		}	
		replace group = "P90-95"		if ptile_w >= 90000  	& ptile_w < 95000
		replace group = "P95-99"		if ptile_w >= 95000  	& ptile_w < 99000
		replace group = "P99-99.5"		if ptile_w >= 99000  	& ptile_w < 99500
		replace group = "P99.5-99.9"	if ptile_w >= 99500 	& ptile_w < 99900
		replace group = "P99.9-P99.95"	if ptile_w >= 99900 	& ptile_w < 99950
		replace group = "P99.95-P99.99"	if ptile_w >= 99950 	& ptile_w < 99990
		replace group = "P99.99-P100"	if ptile_w >= 99990 	

		qui su mwealth [w=weight], meanonly
			local totwealth = r(sum)
		qui su income [w=weight], meanonly
			local totinc = r(sum)

		collapse (first) ctry (sum) mwealth income tax [fw=weight], by(group)
		replace mwealth = mwealth / `totwealth'
		replace income = income / `totinc'
		gen totinc = `totinc'
		gen totwealth = `totwealth'
		replace tax = tax / (income * totinc)
		rename tax tax_rate
		order ctry group mwealth income totinc totwealth tax_rate
		export excel using "$out_distrib", sheetmodify first(var) sh(inc_`ctry')
	}

	use "$root/WorkScandinavia/Output/evasion2006.dta", clear
		gen income_usd = income / fx
		gen wealth_usd = mwealth / fx
		gen tax_usd = tax / fx
		drop ptile_w
		cumul wealth_usd [w=weight], gen(ptile_w)
		replace ptile_w = 100000 * ptile_w
		gen group = "."
		foreach i of numlist 0/9 {
			local j = `i' + 1
			replace group = "P`i'0-`j'0" if ptile_w >= `i'*10000 & ptile_w < `j'*10000
		}	
		replace group = "P90-95"		if ptile_w >= 90000  	& ptile_w < 95000
		replace group = "P95-99"		if ptile_w >= 95000  	& ptile_w < 99000
		replace group = "P99-99.5"		if ptile_w >= 99000  	& ptile_w < 99500
		replace group = "P99.5-99.9"	if ptile_w >= 99500 	& ptile_w < 99900
		replace group = "P99.9-P99.95"	if ptile_w >= 99900 	& ptile_w < 99950
		replace group = "P99.95-P99.99"	if ptile_w >= 99950 	& ptile_w < 99990
		replace group = "P99.99-P100"	if ptile_w >= 99990 	

		qui su wealth_usd [w=weight], meanonly
			local totwealth = r(sum)
		qui su income_usd [w=weight], meanonly
			local totinc = r(sum)

		collapse  (sum) wealth_usd income_usd tax_usd [fw=weight], by(group)
		replace tax_usd = tax_usd / income_usd
		rename tax_usd tax_rate
		replace wealth_usd = wealth_usd / `totwealth'
		replace income_usd = income_usd / `totinc'
		gen totinc_usd = `totinc'
		gen totwealth_usd = `totwealth'
		gen ctry = "All"
		order ctry
		export excel using "$out_distrib", sheetmodify first(var) sh(inc_all)
		putexcel set  "$out_distrib", modify sh(inc_all)
		putexcel A19 = ("Scandinavian numbers in this sheet are from appended g-perc file, not Pareto-interpolated pop-wide file")
