clear
set more off


*Directory for program files
global source 	"\\...\SourceData" 
global progs 	"\\...\CLEAN\prog" 
global data		"\\...\CLEAN\data" 
global output	"\\...\CLEAN\data\output" 
global temp	    "\\...\P0782_Gem\temp"


cap log close
log using $progs\sw_makedata0_auditsCLEAN.log, replace

/*******************************************************************************
 * Info on offshore wealth related audits by the Swedish tax administration
 * 
 * In some cases, both a firm ID and individual ID is registered. 
 * We then use the individual ID as the unit of observation. 
 * 
 * Restrict definition of "evader" to having two conditions fulfilled:
 *    1) case closed AND 
 *    2) value for tax effect.
 *
*******************************************************************************/
 
* Add annual tax amendments due to offshore evasion
use $source\beslut_lev.dta, clear
	   duplicates drop
	   sum    
	   d, fullname
       *only keep observations with true identity and sure penalty tax, by year
	   drop if lopnr==. 
       *year of tax change 
	   rename TAX_R ev_taxyear  
	   replace ev_taxyear="2000" if ev_taxyear=="200,"
	   destring ev_taxyear, replace
       *year of decision
	   destring BESLUTS_R, replace
	   rename BESLUTS_R ev_year_decision
	   label var ev_year_decision "year of decision for evaders"   
	   tab ev_taxyear ev_year_decision , m
	   *only few have missing on decision year. Give them the tax year + 2
	   replace ev_year_decision = ev_taxyear + 2 if ev_year_decision==.
	   tab ev_taxyear ev_year_decision , m
	   *several individual observations also have observation on the firm id, indicating that this has to do with actions in the firm. 
	   gen ev_decision_also_firmid=(lopnr_orgn!=.)
	   tab ev_decision_also_firmid, m
	  *clean the tax variables
	   rename SKATT_ATT_BETALA_INKL_ST ev_annual_taxinc
	   replace ev_annual_taxinc=0 if ev_annual_taxinc==.
	   rename SKATTETILL_GG ev_annual_penalty_tax
	   replace ev_annual_penalty_tax=0 if ev_annual_penalty_tax==.
	   rename lopnr ID
	*make one observation per individual per tax year 
	collapse (first) ev_year_decision (sum) ev_annual_taxinc ev_annual_penalty_tax (max) ev_decision_also_firmid, by(ID ev_taxyear)
	   label var ev_year_decision "decision year"
       label var ev_annual_taxinc "payable tax including penalty tax by taxyear"
       label var ev_annual_penalty_tax "payable penalty tax by taxyear"
       label var ev_decision_also_firmid "penalty tax file also has firm-ID with his ID"
       label var ev_taxyear "taxyear for payable tax"
   
       *tax year is income year+1
       gen year=ev_taxyear-1
       sort ID year
save $temp\taxpanel.dta, replace
   
*what is total taxes due per individual, and for how many tax years?
      gen ev_number_years=1
      replace ev_number_years=0 if ev_annual_taxinc==0 & ev_annual_penalty_tax==0
    collapse (sum) ev_annual_taxinc ev_annual_penalty_tax ev_number_years (min) ev_year_decision , by(ID) 
    rename ev_annual_taxinc ev_total_taxinc
    rename ev_annual_penalty_tax ev_total_penalty_tax
    rename ev_year_decision ev_firstyear_decision
    label var ev_total_taxinc "total payable tax over all years including penalty"
    label var ev_total_penalty_tax "total penalty tax over all years"	
    label var ev_number_years "number of years with tax change"
    label var ev_firstyear_decision "first year of decision from tax file of closed cases"  
    sort ID
save $temp\taxind.dta, replace
    tab ev_firstyear_decision, m
    tab ev_number_years, m
    tab ev_firstyear_decision ev_number_years, m
    sum ev_total_taxinc, det
    sum ev_total_penalty_tax, det
   *how much in total?
    collapse (sum) ev_total_taxinc ev_total_penalty_tax (mean) ev_number_years
    l
   

********************************************************************************
******************************************************************************** 
*Panama papers list, contains both individuals and firms.

use $source\panamapapers_lev.dta, clear
    duplicates drop
    count
    *how many only individual level observations?
    count if lopnr!=. & lopnr_orgnr==.
    *how many individuals are also observed with firm connection?
    count if lopnr!=. & lopnr_orgnr!=. 
    *how many pure firm level observations?
    count if lopnr==. & lopnr_orgnr!=. 
    * save as pure individual level file, keep all indivdiuals, also those with firm level connection
    keep if lopnr!=.
    gen ev_has_panama_firm=(lopnr_orgnr!=.)
    label var ev_has_panama_firm "both individual and firm level panama papers listing"
    drop lopnr_orgnr
    sum
    rename lopnr ID
    gen ev_in_panama_file=1
    label var ev_in_panama_file "included in separate panama file"
    sort ID
save $temp\panama.dta, replace

********************************************************************************
********************************************************************************

use $source\listatillforskare_SUI.dta, clear
    d, fullname
    rename switzerland ev_switzerland
    sum
    keep if lopnr!=.
    rename lopnr ID
    drop lopnr_orgnr
    duplicates drop
    *There are multiple observations in the investigation data set, often due to multiple status variables. 
    *clean that up first now and keep the most recent status 
    tab status, m
    gen ev_status=0
    *not started
    replace ev_status=1 if substr(status,1,5)=="Ident"
    replace ev_status=1 if substr(status,1,5)=="Nyreg"
    replace ev_status=1 if substr(status,1,5)=="Urval"
    *case in process
    replace ev_status=2 if substr(status,1,3)=="Ana"
    replace ev_status=2 if substr(status,14,8)=="till obj"
    replace ev_status=2 if substr(status,4,12)=="granskning p"
    replace ev_status=2 if substr(status,1,11)=="Utredning p"
    * case handed over to other control
    replace ev_status=3 if substr(status,2,4)=="verl"
    *case closed, no decision
    replace ev_status=4 if substr(status,11,16)=="ing avslutad, ej"
    *case closed
    replace ev_status=5 if substr(status,1,11)=="Utredning a"
    * there is a variable indicating whether there is a decision in the case
    gen ev_has_decision = (beslut=="Yes")
    tab ev_status ev_has_decision, m
 
    * Reason for starting the investigation
    tab reason, m
    rename reason ev_reason
    gen ev_r_transfers=(ev_reason=="Foreign bank transfers")
    replace ev_r_transfers=. if ev_reason==""
    gen ev_r_creditcard=(ev_reason=="Foreign credit card")
    replace ev_r_creditcard=. if ev_reason==""
    gen ev_r_other=(ev_reason=="Other")
    replace ev_r_other=. if ev_reason==""
    gen ev_r_panama=(ev_reason=="Panama Leak")
    replace ev_r_panama=. if ev_reason==""
    gen ev_r_missing=(ev_reason=="")

    *timing 
    rename registrerat ev_date_case_registered
    rename UTREDNING_P_B_RJAD ev_date_start_investigation
    rename UTREDNING_AVSLUTAD ev_date_closed_investigation 
    gen ev_year_case_registered = substr(ev_date_case_registered,7,4)
    gen ev_start_investigation = substr(ev_date_start_investigation,7,4)
    gen ev_year_closed_investigation = substr(ev_date_closed_investigation,7,4)

    *Countries of investigation
    rename UTREDNINGSL_NDER ev_countries
    tab ev_countries, m
    *there are a lot of missing countries
    tab ev_year_case_registered, m
    tab ev_year_case_registered if ev_countries=="", m 
    bysort ev_year_case_registered:  tab  ev_sw* ev_reason, m
    bysort ev_year_case_registered:  tab  ev_sw* ev_reason if ev_countries!="", m
 
    *make dummies:
    gen ev_case_closed=(ev_status==5)
    replace ev_case_closed=. if ev_status==.
    gen ev_case_dropped=(ev_status==4)
    replace ev_case_dropped=. if ev_status==.
    gen ev_case_othercontr=(ev_status==3)
    replace ev_case_othercontr=. if ev_status==.
    gen ev_case_in_process=(ev_status==2)
    replace ev_case_in_process=. if ev_status==.  
    gen ev_case_not_started=(ev_status==1)
    replace ev_case_not_started=. if ev_status==.
    label var ev_case_closed "case closed" 
    label var ev_case_dropped "case dropped after brief initial review" 
    label var ev_case_othercontr "case passed to other control" 
    label var ev_case_in_process "case in process" 
    label var ev_case_not_started "case not started"
    label var ev_countries "Countries of investigation offshore evasion"
    label var ev_r_creditcard "use of foreign card reason for investigation"
    label var ev_r_transfers "foreign bank transfers reason for investigation"
    label var ev_r_other "other reason for investigation"
    label var ev_r_panama "panama papers reason for investigation"
    label var ev_r_missing "missing reason for investigation"
    label var ev_reason "reason for starting investigation"
    label var ev_has_decision "case closed with a decision"  
    keep ID ev_* 
    sort ID ev_status
	compress 
 save $data\ev_panel_multipleIDobs.dta, replace
    sum
 
    *to get any meaningful info on number of cases, reduce this to one observation per individualk.
    *keep the one with the higher status code, which is the later one

    sort ID ev_status 
    by ID: keep if _n==_N
    sum
    tab ev_countries, m
    tab ev_year_case_registered, m
    tab ev_year_case_registered if ev_countries=="", m
    bysort ev_year_case_registered:  tab  ev_sw* ev_reason, m
    bysort ev_year_case_registered:  tab  ev_sw* ev_reason if ev_countries!="", m
 
    *add on additional data from the pananapapers and the computed taxes files
    sort ID
    merge 1:1 ID using $temp\taxind.dta
    drop _m
    merge 1:1 ID using $temp\panama.dta
    drop _m
 
    * require that also postive tax effect and case closed in order to define as caught evader
    * but, according to case workers, could treat all suspected evaders as evaders, many reasons 
    * for closing a case, they could potentially voluntary disclosed.
    gen ev_evader=((ev_has_decision==1 | ev_date_closed_investigation!="") & ev_total_taxinc<. & ev_total_taxinc>0)
    label var ev_evader "evades at some point-case closed with tax effects"
    d, fullname
    sum
    tab ev_r_panama ev_in_panama_file, m
    sort ID
	compress
save $data\ev_panel_only1.dta, replace
 
********************************************************************************

clear
log close



